"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MssqlDbRunner = void 0;
const testcontainers_1 = require("testcontainers");
const db_runner_abstract_1 = require("./db-runner.abstract");
class MssqlDbRunner extends db_runner_abstract_1.DbRunnerAbstract {
    static startContainer(options) {
        const version = process.env.TEST_MSSQL_VERSION || options.version || '2019-latest';
        const container = new testcontainers_1.GenericContainer(`mcr.microsoft.com/mssql/server:${version}`)
            .withEnvironment({
            ACCEPT_EULA: 'Y',
            MSSQL_SA_PASSWORD: process.env.TEST_DB_PASSWORD || 'Test1test',
        })
            .withExposedPorts(1433)
            .withWaitStrategy(testcontainers_1.Wait.forLogMessage('Service Broker manager has started'))
            .withStartupTimeout(30 * 1000);
        if (options.volumes) {
            const binds = options.volumes.map(v => ({ source: v.source, target: v.target, mode: v.bindMode }));
            container.withBindMounts(binds);
        }
        return container.start();
    }
}
exports.MssqlDbRunner = MssqlDbRunner;
//# sourceMappingURL=mssql.js.map